@@ -194,6 +194,28 @@ class TestSmartRepresentationCase(IntegrationCase):
 
         self.assertEqual(expected, actual)
 
+    def test_metadata(self) -> None:
+        self.smart.lab.metadata = Mock(return_value=dict(user='user'))  # type: ignore
+
+        actual = self.smart.metadata()
+
+        self.assertSetEqual({'user', 'params'}, set(actual))
+
+    def test_metadata__save(self) -> None:
+        self.smart.lab.metadata = Mock(return_value=dict(user='user'))  # type: ignore
+
+        with tempfile.TemporaryDirectory() as dirname:
+            filepath = Path(dirname, 'meta.yaml')
+            filepath.write_text('run001:\n  user: root\n  params: sth')
+            self.smart.lab._git_root_dir = Path(dirname)
+
+            self.smart.metadata(save_to=filepath)
+
+            self.assertEqual(
+                'run001:\n  user: root\n  params: sth\nrun002:\n  user: user\n  params: {}\n',
+                filepath.read_text(),
+            )
+
 
 class TestCheckCase(IntegrationCase):
     def setUp(self) -> None:
